@@ -26,8 +26,7 @@ impl LamellarAM for DataAM {
             let local = lamellar::team.alloc_local_mem_region::<u8>(self.length);
             let local_slice = local.as_mut_slice().unwrap();
             local_slice[self.length - 1] = 255u8;
-            self.array
-                .get_unchecked(self.index, local.clone());
+            self.array.get_unchecked(self.index, local.clone());
 
             while local_slice[self.length - 1] == 255u8 {
                 async_std::task::yield_now().await;
@@ -47,7 +46,7 @@ fn main() {
             *i = my_pe as u8;
         }
     }
-    unsafe { array.put( 0, data.clone()) };
+    unsafe { array.put(0, data.clone()) };
     world.barrier();
     let s = Instant::now();
     world.barrier();
