@@ -5,7 +5,7 @@
 use lamellar::RemoteMemoryRegion;
 use std::time::Instant;
 
-const MEMREG_LEN: usize = 1024 * 1024 * 1024;
+const MEMREG_LEN: usize = 2 * 1024 * 1024 * 1024;
 
 fn main() {
     let world = lamellar::LamellarWorldBuilder::new().build();
