@@ -7,7 +7,7 @@ use std::any::TypeId;
 use std::collections::HashMap;
 use parking_lot::Mutex;
 
-type OpFn = fn(*const u8, CollectiveAtomicByteArray, usize) -> LamellarArcAm;
+type OpFn = fn(*const u8, LocalLockAtomicByteArray, usize) -> LamellarArcAm;
 
 lazy_static! {
     static ref OPS: HashMap<(ArrayOpCmd, TypeId), OpFn> = {
@@ -26,7 +26,7 @@ pub struct LocalLockAtomicArrayOp {
 
 crate::inventory::collect!(LocalLockAtomicArrayOp);
 
-type BufFn = fn(CollectiveAtomicByteArray) -> Arc<dyn BufferOp>;
+type BufFn = fn(LocalLockAtomicByteArray) -> Arc<dyn BufferOp>;
 
 lazy_static! {
         pub(crate) static ref BUFOPS: HashMap<TypeId, BufFn> = {
@@ -46,7 +46,7 @@ pub struct LocalLockAtomicArrayOpBuf {
 crate::inventory::collect!(LocalLockAtomicArrayOpBuf);
 
 impl<T: AmDist + Dist + 'static> LocalLockAtomicArray<T> {
-    fn initiate_op(
+    fn initiate_op<'a>(
         &self,
         index: usize,
         val: T,
@@ -55,7 +55,7 @@ impl<T: AmDist + Dist + 'static> LocalLockAtomicArray<T> {
     ) -> Option<Box<dyn LamellarRequest<Output = ()> + Send + Sync>> {
         // println!("initiate_op for LocalLockAtomicArray<T> ");
         if let Some(func) = OPS.get(&(op, TypeId::of::<T>())) {
-            let array: CollectiveAtomicByteArray = self.clone().into();
+            let array: LocalLockAtomicByteArray = self.clone().into();
             let pe = self.pe_for_dist_index(index).expect("index out of bounds");
             let am = func(&val as *const T as *const u8, array, local_index);
             // Some(self.inner.team.exec_arc_am_pe(
@@ -79,7 +79,7 @@ impl<T: AmDist + Dist + 'static> LocalLockAtomicArray<T> {
         }
     }
 
-    fn initiate_fetch_op(
+    fn initiate_fetch_op<'a>(
         &self,
         index: usize,
         val: T,
@@ -88,7 +88,7 @@ impl<T: AmDist + Dist + 'static> LocalLockAtomicArray<T> {
     ) -> Box<dyn LamellarRequest<Output = T> + Send + Sync> {
         // println!("initiate_op for LocalLockAtomicArray<T> ");
         if let Some(func) = OPS.get(&(op, TypeId::of::<T>())) {
-            let array: CollectiveAtomicByteArray = self.clone().into();
+            let array: LocalLockAtomicByteArray = self.clone().into();
             let pe = self.pe_for_dist_index(index).expect("index out of bounds");
             let am = func(&val as *const T as *const u8, array, local_index);
             // self.inner.team.exec_arc_am_pe(
@@ -127,7 +127,7 @@ impl<T: AmDist + Dist + 'static> LocalLockAtomicArray<T> {
         }
     }
 
-    pub fn load(&self, index: usize) -> Box<dyn LamellarRequest<Output = T> + Send + Sync> {
+    pub fn load<'a>(&self, index: impl OpInput<'a,usize>,) -> Box<dyn LamellarRequest<Output = T> + Send + Sync> {
         let pe = self.pe_for_dist_index(index).expect("index out of bounds");
         let local_index = self.pe_offset_for_dist_index(pe, index).unwrap(); //calculated pe above
         let dummy_val = self.array.dummy_val(); //we dont actually do anything with this except satisfy apis;
