@@ -54,6 +54,7 @@ pub struct UnsafeByteArray {
 pub(crate) struct UnsafeArrayInner {
     pub(crate) data: Darc<UnsafeArrayData>,
     pub(crate) distribution: Distribution,
+    // wait: Darc<AtomicUsize>,
     orig_elem_per_pe: f64,
     elem_size: usize, //for bytes array will be size of T, for T array will be 1
     offset: usize,    //relative to size of T
@@ -95,7 +96,7 @@ impl<T: Dist + 'static> UnsafeArray<T> {
             UnsafeArrayData {
                 mem_region: rmr,
                 array_counters: Arc::new(AMCounters::new()),
-                team: team,
+                team: team.clone(),
                 my_pe: my_pe,
                 num_pes: num_pes,
                 // op_buffers: Mutex::new(HashMap::new()),
@@ -105,10 +106,17 @@ impl<T: Dist + 'static> UnsafeArray<T> {
             crate::darc::DarcMode::Darc,
         )
         .expect("trying to create array on non team member");
+        // let wait = Darc::try_new(
+        //     team.clone(),
+        //     AtomicUsize::new(0),
+        //     crate::darc::DarcMode::Darc,
+        // )
+        // .expect("trying to create array on non team member");
         let array = UnsafeArray {
             inner: UnsafeArrayInner {
                 data: data,
                 distribution: distribution.clone(),
+                // wait: wait,
                 orig_elem_per_pe: elem_per_pe,
                 elem_size: std::mem::size_of::<T>(),
                 offset: 0,        //relative to size of T
@@ -117,6 +125,11 @@ impl<T: Dist + 'static> UnsafeArray<T> {
             phantom: PhantomData,
         };
         // println!("new unsafe");
+        // unsafe {println!("size {:?} bytes {:?}",array.inner.size, array.inner.data.mem_region.as_mut_slice().unwrap().len())};
+        // println!("elem per pe {:?}", elem_per_pe);
+        // for i in 0..num_pes{
+        //     println!("pe: {:?} {:?}",i,array.inner.num_elems_pe(i));
+        // }
         // array.inner.data.print();
         array.create_buffered_ops();
         // println!("after buffered ops");
@@ -239,8 +252,18 @@ impl<T: Dist + 'static> UnsafeArray<T> {
     pub fn into_local_lock_atomic(self) -> LocalLockAtomicArray<T> {
         self.into()
     }
+
+    pub fn into_generic_atomic(self) -> GenericAtomicArray<T> {
+        self.into()
+    }
 }
 
+// impl<T: Dist> UnsafeArray<T> {
+//     pub fn into_native_atomic(self) -> NativeAtomicArray<T> {
+//         self.into()
+//     }
+// }
+
 impl<T: Dist + 'static> UnsafeArray<T> {
     pub fn into_atomic(self) -> AtomicArray<T> {
         self.into()
@@ -249,6 +272,28 @@ impl<T: Dist + 'static> UnsafeArray<T> {
 
 impl<T: Dist> From<AtomicArray<T>> for UnsafeArray<T> {
     fn from(array: AtomicArray<T>) -> Self {
+        // // let array = array.into_data();
+        // match array{
+        //     AtomicArray::NativeAtomicArray(array) => array.into()
+
+        //     }
+        // }
+        array.into()
+    }
+}
+
+impl<T: Dist> From<NativeAtomicArray<T>> for UnsafeArray<T> {
+    fn from(array: NativeAtomicArray<T>) -> Self {
+        // let array = array.into_data();
+        array.array.block_on_outstanding(DarcMode::UnsafeArray);
+        array.array.inner.data.op_buffers.write().clear();
+        array.array.create_buffered_ops();
+        array.array
+    }
+}
+
+impl<T: Dist> From<GenericAtomicArray<T>> for UnsafeArray<T> {
+    fn from(array: GenericAtomicArray<T>) -> Self {
         // let array = array.into_data();
         array.array.block_on_outstanding(DarcMode::UnsafeArray);
         array.array.inner.data.op_buffers.write().clear();
@@ -533,12 +578,15 @@ impl UnsafeArrayInner {
         }
     }
 
+    //index relative to subarray, return local offset relative to full array
     // pub fn pe_full_offset_for_dist_index(&self, pe: usize, index: usize) -> Option<usize> {
     //     let global_index = self.offset + index;
+    //     println!("{:?} {:?} {:?}",global_index, self.offset, index);
     //     match self.distribution {
     //         Distribution::Block => {
     //             let pe_start_index = (self.orig_elem_per_pe * pe as f64).round() as usize;
     //             let pe_end_index = (self.orig_elem_per_pe * (pe+1) as f64).round() as usize;
+    //             println!("{:?} {:?}",pe_start_index,pe_end_index);
     //             if pe_start_index <= global_index && global_index < pe_end_index{
     //                 Some(global_index - pe_start_index)
     //             }
@@ -558,6 +606,32 @@ impl UnsafeArrayInner {
     //     }
     // }
 
+    pub fn pe_full_offset_for_local_index(&self, pe: usize, index: usize) -> Option<usize> {
+        // let global_index = self.offset + index;
+        let global_index = self.global_index_from_local(index)?;
+        // println!("{:?} {:?} {:?}",global_index, self.offset, index);
+        match self.distribution {
+            Distribution::Block => {
+                let pe_start_index = (self.orig_elem_per_pe * pe as f64).round() as usize;
+                let pe_end_index = (self.orig_elem_per_pe * (pe + 1) as f64).round() as usize;
+                // println!("{:?} {:?}",pe_start_index,pe_end_index);
+                if pe_start_index <= global_index && global_index < pe_end_index {
+                    Some(global_index - pe_start_index)
+                } else {
+                    None
+                }
+            }
+            Distribution::Cyclic => {
+                let num_pes = self.data.num_pes;
+                if global_index % num_pes == pe {
+                    Some(global_index / num_pes)
+                } else {
+                    None
+                }
+            }
+        }
+    }
+
     //index is local with respect to subarray
     //returns index with respect to original full length array
     pub(crate) fn global_index_from_local(&self, index: usize) -> Option<usize> {
@@ -590,9 +664,10 @@ impl UnsafeArrayInner {
             Distribution::Cyclic => {
                 let num_pes = self.data.num_pes;
                 let start_pe = self.pe_for_dist_index(0).unwrap();
-                let end_pe = self.pe_for_dist_index(self.size).unwrap();
+                let end_pe = self.pe_for_dist_index(self.size - 1).unwrap();
 
                 let mut num_elems = self.size / num_pes;
+                // println!("{:?} {:?} {:?} {:?}",num_pes,start_pe,end_pe,num_elems);
 
                 if self.size % num_pes != 0 {
                     //we have leftover elements
@@ -608,12 +683,13 @@ impl UnsafeArrayInner {
                         }
                     }
                 }
+                // println!("{:?} {:?} {:?} {:?}",num_pes,start_pe,end_pe,num_elems);
 
                 if index < num_elems {
                     if start_pe <= my_pe {
-                        Some(self.size * index + self.offset + (my_pe - start_pe))
+                        Some(num_pes * index + self.offset + (my_pe - start_pe))
                     } else {
-                        Some(self.size * index + self.offset + (num_pes - start_pe) + my_pe)
+                        Some(num_pes * index + self.offset + (num_pes - start_pe) + my_pe)
                     }
                 } else {
                     None
@@ -767,7 +843,7 @@ impl UnsafeArrayInner {
                     0
                 };
                 let end_index = start_index + num_elems_local;
-                // println!("nel {:?} sao {:?} as slice si: {:?} ei {:?}",num_elems_local,self.offset,start_index,end_index);
+                // println!("nel {:?} sao {:?} as slice si: {:?} ei {:?} elemsize {:?}",num_elems_local,self.offset,start_index,end_index,self.elem_size);
                 &mut slice[start_index * self.elem_size..end_index * self.elem_size]
             }
             Distribution::Cyclic => {
