@@ -33,7 +33,9 @@ pub(crate) enum DarcMode {
     UnsafeArray,
     ReadOnlyArray,
     LocalOnlyArray,
-    AtomicArray,
+    // AtomicArray,
+    GenericAtomicArray,
+    NativeAtomicArray,
     LocalLockAtomicArray,
 }
 
