@@ -63,8 +63,12 @@ fn default_backend() -> Backend {
                 #[cfg(not(feature = "enable-rofi"))]
                 panic!("unable to set rofi backend, recompile with 'enable-rofi' feature")
             }
-            "shmem" => {return Backend::Shmem;}
-            _ => {return Backend::Local;}
+            "shmem" => {
+                return Backend::Shmem;
+            }
+            _ => {
+                return Backend::Local;
+            }
         },
         Err(_) => {
             #[cfg(feature = "enable-rofi")]
