@@ -101,6 +101,7 @@ mod lamellae;
 mod lamellar_alloc;
 mod lamellar_arch;
 mod lamellar_request;
+mod lamellar_task_group;
 mod lamellar_team;
 mod lamellar_world;
 mod memregion;
@@ -139,6 +140,7 @@ pub use crate::memregion::{
 
 pub use crate::lamellae::Backend;
 pub use crate::lamellar_arch::{BlockedArch, IdError, LamellarArch, StridedArch};
+pub use crate::lamellar_task_group::LamellarTaskGroup;
 pub use crate::lamellar_world::*;
 pub use crate::scheduler::SchedulerType;
 
