@@ -90,7 +90,7 @@ macro_rules! sub_test{
                         reqs.push(array.fetch_sub(idx,1 as $t));
                     }
                     for req in reqs{
-                        let val = req.get().unwrap();
+                        let val = req.get().unwrap()[0];
                         if val > prev{
                             success = false;
                         }
@@ -178,7 +178,7 @@ macro_rules! sub_test{
                         reqs.push(sub_array.fetch_sub(idx,1 as $t));
                     }
                     for req in reqs{
-                        let val = req.get().unwrap();
+                        let val = req.get().unwrap()[0];
                         if val > prev{
                             success = false;
                         }
@@ -267,7 +267,7 @@ macro_rules! sub_test{
                             reqs.push(sub_array.fetch_sub(idx,1 as $t));
                         }
                         for req in reqs{
-                            let val = req.get().unwrap();
+                            let val = req.get().unwrap()[0];
                             if val > prev{
                                 success = false;
                             }
